@@ -19,11 +19,15 @@
 #define OPKG_CONF_H
 
 typedef struct opkg_conf opkg_conf_t;
+extern opkg_conf_t *conf;
+
+#include <stdarg.h>
+
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 #include "hash_table.h"
-#include "args.h"
-#include "pkg.h"
-#include "pkg_hash.h"
 #include "pkg_src_list.h"
 #include "pkg_dest_list.h"
 #include "nv_pair_list.h"
@@ -32,6 +36,8 @@ typedef struct opkg_conf opkg_conf_t;
 #define OPKG_CONF_TMP_DIR_SUFFIX "opkg-XXXXXX"
 #define OPKG_CONF_LISTS_DIR  OPKG_STATE_DIR_PREFIX "/lists"
 
+#define OPKG_CONF_DEFAULT_CONF_FILE_DIR OPKGETCDIR"/opkg"
+
 /* In case the config file defines no dest */
 #define OPKG_CONF_DEFAULT_DEST_NAME "root"
 #define OPKG_CONF_DEFAULT_DEST_ROOT_DIR "/"
@@ -40,17 +46,26 @@ typedef struct opkg_conf opkg_conf_t;
 
 struct opkg_conf
 {
-     int lock_fd; /* file descriptor for the lock file */
      pkg_src_list_t pkg_src_list;
+     pkg_src_list_t dist_src_list;
      pkg_dest_list_t pkg_dest_list;
+     pkg_dest_list_t tmp_dest_list;
      nv_pair_list_t arch_list;
 
      int restrict_to_default_dest;
      pkg_dest_t *default_dest;
+     char *dest_str;
+
+     char *conf_file;
 
      char *tmp_dir;
      char *lists_dir;
 
+     unsigned int pfm; /* package field mask */
+
+     /* For libopkg users to capture messages. */
+     void (*opkg_vmessage)(int, const char *fmt, va_list ap);
+
      /* options */
      int autoremove;
      int force_depends;
@@ -62,19 +77,23 @@ struct opkg_conf
      int force_space;
      int force_removal_of_dependent_packages;
      int force_removal_of_essential_packages;
+     int force_postinstall;
+     int force_remove;
+     int prefer_arch_to_version;
      int check_signature;
-     int nodeps; /* do not follow dependences */
+     int nodeps; /* do not follow dependencies */
      char *offline_root;
-     char *offline_root_path;
-     char *offline_root_pre_script_cmd;
-     char *offline_root_post_script_cmd;
+     char *overlay_root;
      int query_all;
      int verbosity;
      int noaction;
+     int download_only;
      char *cache;
 
-#ifdef HAVE_SSLCURL
-     /* some options could be used by
+     /* ssl-curl options: used only when opkg is configured with
+      * '--enable-ssl-curl', otherwise always NULL or 0.
+      *
+      * some options could be used by
       * wget if curl support isn't builtin
       * If someone want to try...
       */
@@ -87,10 +106,11 @@ struct opkg_conf
      char *ssl_ca_file;
      char *ssl_ca_path;
      int ssl_dont_verify_peer;
-#endif
-#ifdef HAVE_PATHFINDER
+
+     /* pathfinder options: used only when opkg is configured with
+      * '--enable-pathfinder', otherwise always NULL or 0 as above.
+      */
      int check_x509_path;
-#endif
 
      /* proxy options */
      char *http_proxy;
@@ -118,16 +138,18 @@ typedef struct opkg_option opkg_option_t;
 struct opkg_option {
      const char *name;
      const opkg_option_type_t type;
-     const void *value;
+     void * const value;
 };
 
-int opkg_conf_init(opkg_conf_t *conf, const args_t *args);
-void opkg_conf_deinit(opkg_conf_t *conf);
+int opkg_conf_init(void);
+int opkg_conf_load(void);
+void opkg_conf_deinit(void);
 
-int opkg_conf_write_status_files(opkg_conf_t *conf);
-char *root_filename_alloc(opkg_conf_t *conf, char *filename);
-
-
-void opkg_init_options_array(const opkg_conf_t *conf, opkg_option_t **options);
+int opkg_conf_write_status_files(void);
+char *root_filename_alloc(char *filename);
 
+#ifdef __cplusplus
+}
 #endif
+
+#endif /* OPKG_CONF_H */
